# eric7.QScintilla.DocstringGenerator.EricdocGenerator

Module implementing the docstring generator for the 'ericdoc' style.

### Global Attributes

None

### Classes

None

### Functions

generateDoc | Function to generate the docstring line list iaw.

## generateDoc

generateDoc(functionInfo, _editor)

Function to generate the docstring line list iaw. eric documentation style.

Note: Text is created with DESCRIPTION placeholders for descriptions and TYPE placeholders for type information

functionInfo (FunctionInfo)
  object containing the function information to base the docstring on
_editor (Editor)
  reference to the editor (unused)

Return:
  list of docstring lines

Return Type:
  str

Up